import { __assign, __extends, __decorate, __param } from 'tslib';
import { InjectionToken, NgZone, Optional, Inject, ɵɵdefineInjectable, ɵɵinject, Injectable, Pipe, SkipSelf, NgModule } from '@angular/core';
import { ApolloClient, Observable as Observable$1, ApolloLink } from '@apollo/client/core';
export { ApolloCache, ApolloClient, ApolloError, ApolloLink, Cache, InMemoryCache, Observable as LinkObservable, NetworkStatus, ObservableQuery, concat, defaultDataIdFromObject, empty, execute, from, fromError, getMainDefinition, gql, isApolloError, split, throwServerError } from '@apollo/client/core';
import { Observable, queueScheduler, observable, from } from 'rxjs';
import { observeOn, share, startWith } from 'rxjs/operators';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import { print } from 'graphql';
import { extractFiles } from 'extract-files';
import { BatchLink } from 'apollo-link-batch';

function fromPromise(promiseFn) {
    return new Observable(function (subscriber) {
        promiseFn().then(function (result) {
            if (!subscriber.closed) {
                subscriber.next(result);
                subscriber.complete();
            }
        }, function (error) {
            if (!subscriber.closed) {
                subscriber.error(error);
            }
        });
        return function () { return subscriber.unsubscribe(); };
    });
}
var ZoneScheduler = /** @class */ (function () {
    function ZoneScheduler(zone) {
        this.zone = zone;
        this.now = Date.now ? Date.now : function () { return +new Date(); };
    }
    ZoneScheduler.prototype.schedule = function (work, delay, state) {
        if (delay === void 0) { delay = 0; }
        return this.zone.run(function () {
            return queueScheduler.schedule(work, delay, state);
        });
    };
    return ZoneScheduler;
}());
function fixObservable(obs) {
    obs[observable] = function () { return obs; };
    return obs;
}
function wrapWithZone(obs, ngZone) {
    return obs.pipe(observeOn(new ZoneScheduler(ngZone)));
}
function pickFlag(flags, flag, defaultValue) {
    return flags && typeof flags[flag] !== 'undefined'
        ? flags[flag]
        : defaultValue;
}

var QueryRef = /** @class */ (function () {
    function QueryRef(obsQuery, ngZone, options) {
        this.obsQuery = obsQuery;
        var wrapped = wrapWithZone(from(fixObservable(this.obsQuery)), ngZone).pipe(share());
        this.valueChanges = options.useInitialLoading
            ? wrapped.pipe(startWith(__assign(__assign({}, this.obsQuery.getCurrentResult()), { error: undefined, partial: undefined, stale: true })))
            : wrapped;
    }
    Object.defineProperty(QueryRef.prototype, "queryId", {
        // ObservableQuery's methods
        get: function () {
            return this.obsQuery.queryId;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(QueryRef.prototype, "queryName", {
        get: function () {
            return this.obsQuery.queryName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(QueryRef.prototype, "variables", {
        get: function () {
            return this.obsQuery.variables;
        },
        enumerable: true,
        configurable: true
    });
    QueryRef.prototype.result = function () {
        return this.obsQuery.result();
    };
    QueryRef.prototype.getCurrentResult = function () {
        return this.obsQuery.getCurrentResult();
    };
    QueryRef.prototype.isDifferentFromLastResult = function (newResult) {
        return this.obsQuery.isDifferentFromLastResult(newResult);
    };
    QueryRef.prototype.getLastResult = function () {
        return this.obsQuery.getLastResult();
    };
    QueryRef.prototype.getLastError = function () {
        return this.obsQuery.getLastError();
    };
    QueryRef.prototype.resetLastResults = function () {
        return this.obsQuery.resetLastResults();
    };
    QueryRef.prototype.refetch = function (variables) {
        return this.obsQuery.refetch(variables);
    };
    QueryRef.prototype.fetchMore = function (fetchMoreOptions) {
        return this.obsQuery.fetchMore(fetchMoreOptions);
    };
    QueryRef.prototype.subscribeToMore = function (options) {
        // XXX: there's a bug in @apollo/client typings
        // it should not inherit types from ObservableQuery
        return this.obsQuery.subscribeToMore(options);
    };
    QueryRef.prototype.updateQuery = function (mapFn) {
        return this.obsQuery.updateQuery(mapFn);
    };
    QueryRef.prototype.stopPolling = function () {
        return this.obsQuery.stopPolling();
    };
    QueryRef.prototype.startPolling = function (pollInterval) {
        return this.obsQuery.startPolling(pollInterval);
    };
    QueryRef.prototype.setOptions = function (opts) {
        return this.obsQuery.setOptions(opts);
    };
    QueryRef.prototype.setVariables = function (variables, tryFetch, fetchResults) {
        if (tryFetch === void 0) { tryFetch = false; }
        if (fetchResults === void 0) { fetchResults = true; }
        return this.obsQuery.setVariables(variables, tryFetch, fetchResults);
    };
    return QueryRef;
}());

var APOLLO_FLAGS = new InjectionToken('[apollo-angular] flags');
var APOLLO_OPTIONS = new InjectionToken('[apollo-angular] options');
var APOLLO_NAMED_OPTIONS = new InjectionToken('[apollo-angular] named options');

var ApolloBase = /** @class */ (function () {
    function ApolloBase(ngZone, flags, _client) {
        this.ngZone = ngZone;
        this.flags = flags;
        this._client = _client;
        this.useInitialLoading = pickFlag(flags, 'useInitialLoading', false);
    }
    ApolloBase.prototype.watchQuery = function (options) {
        return new QueryRef(this.ensureClient.watchQuery(__assign({}, options)), this.ngZone, __assign({ useInitialLoading: this.useInitialLoading }, options));
    };
    ApolloBase.prototype.query = function (options) {
        var _this = this;
        return fromPromise(function () {
            return _this.ensureClient.query(__assign({}, options));
        });
    };
    ApolloBase.prototype.mutate = function (options) {
        var _this = this;
        return fromPromise(function () {
            return _this.ensureClient.mutate(__assign({}, options));
        });
    };
    ApolloBase.prototype.subscribe = function (options, extra) {
        var obs = from(fixObservable(this.ensureClient.subscribe(__assign({}, options))));
        return extra && extra.useZone !== true
            ? obs
            : wrapWithZone(obs, this.ngZone);
    };
    /**
     * Get an access to an instance of ApolloClient
     * @deprecated use `apollo.client` instead
     */
    ApolloBase.prototype.getClient = function () {
        return this._client;
    };
    /**
     * Set a new instance of ApolloClient
     * Remember to clean up the store before setting a new client.
     *
     * @deprecated use `apollo.client = client` instead
     * @param client ApolloClient instance
     */
    ApolloBase.prototype.setClient = function (client) {
        this.client = client;
    };
    Object.defineProperty(ApolloBase.prototype, "client", {
        /**
         * Get an access to an instance of ApolloClient
         */
        get: function () {
            return this._client;
        },
        /**
         * Set a new instance of ApolloClient
         * Remember to clean up the store before setting a new client.
         *
         * @param client ApolloClient instance
         */
        set: function (client) {
            if (this._client) {
                throw new Error('Client has been already defined');
            }
            this._client = client;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ApolloBase.prototype, "ensureClient", {
        get: function () {
            this.checkInstance();
            return this._client;
        },
        enumerable: true,
        configurable: true
    });
    ApolloBase.prototype.checkInstance = function () {
        if (!this._client) {
            throw new Error('Client has not been defined yet');
        }
    };
    return ApolloBase;
}());
var Apollo = /** @class */ (function (_super) {
    __extends(Apollo, _super);
    function Apollo(_ngZone, apolloOptions, apolloNamedOptions, flags) {
        var _this = _super.call(this, _ngZone, flags) || this;
        _this._ngZone = _ngZone;
        _this.map = new Map();
        if (apolloOptions) {
            _this.createDefault(apolloOptions);
        }
        if (apolloNamedOptions && typeof apolloNamedOptions === 'object') {
            for (var name_1 in apolloNamedOptions) {
                if (apolloNamedOptions.hasOwnProperty(name_1)) {
                    var options = apolloNamedOptions[name_1];
                    _this.createNamed(name_1, options);
                }
            }
        }
        return _this;
    }
    /**
     * Create an instance of ApolloClient
     * @param options Options required to create ApolloClient
     * @param name client's name
     */
    Apollo.prototype.create = function (options, name) {
        if (isDefault(name)) {
            this.createDefault(options);
        }
        else {
            this.createNamed(name, options);
        }
    };
    /**
     * Use a default ApolloClient
     */
    Apollo.prototype.default = function () {
        return this;
    };
    /**
     * Use a named ApolloClient
     * @param name client's name
     */
    Apollo.prototype.use = function (name) {
        if (isDefault(name)) {
            return this.default();
        }
        return this.map.get(name);
    };
    /**
     * Create a default ApolloClient, same as `apollo.create(options)`
     * @param options ApolloClient's options
     */
    Apollo.prototype.createDefault = function (options) {
        if (this.getClient()) {
            throw new Error('Apollo has been already created.');
        }
        return this.setClient(new ApolloClient(options));
    };
    /**
     * Create a named ApolloClient, same as `apollo.create(options, name)`
     * @param name client's name
     * @param options ApolloClient's options
     */
    Apollo.prototype.createNamed = function (name, options) {
        if (this.map.has(name)) {
            throw new Error("Client " + name + " has been already created");
        }
        this.map.set(name, new ApolloBase(this._ngZone, this.flags, new ApolloClient(options)));
    };
    /**
     * Remember to clean up the store before removing a client
     * @param name client's name
     */
    Apollo.prototype.removeClient = function (name) {
        if (isDefault(name)) {
            this._client = undefined;
        }
        else {
            this.map.delete(name);
        }
    };
    Apollo.ctorParameters = function () { return [
        { type: NgZone },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [APOLLO_OPTIONS,] }] },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [APOLLO_NAMED_OPTIONS,] }] },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [APOLLO_FLAGS,] }] }
    ]; };
    Apollo.ɵprov = ɵɵdefineInjectable({ factory: function Apollo_Factory() { return new Apollo(ɵɵinject(NgZone), ɵɵinject(APOLLO_OPTIONS, 8), ɵɵinject(APOLLO_NAMED_OPTIONS, 8), ɵɵinject(APOLLO_FLAGS, 8)); }, token: Apollo, providedIn: "root" });
    Apollo = __decorate([
        Injectable({
            providedIn: 'root',
        }),
        __param(1, Optional()),
        __param(1, Inject(APOLLO_OPTIONS)),
        __param(2, Optional()),
        __param(2, Inject(APOLLO_NAMED_OPTIONS)),
        __param(3, Optional()), __param(3, Inject(APOLLO_FLAGS))
    ], Apollo);
    return Apollo;
}(ApolloBase));
function isDefault(name) {
    return !name || name === 'default';
}

var Query = /** @class */ (function () {
    function Query(apollo) {
        this.apollo = apollo;
        this.client = 'default';
    }
    Query.prototype.watch = function (variables, options) {
        return this.apollo.use(this.client).watchQuery(__assign(__assign({}, options), { variables: variables, query: this.document }));
    };
    Query.prototype.fetch = function (variables, options) {
        return this.apollo.use(this.client).query(__assign(__assign({}, options), { variables: variables, query: this.document }));
    };
    Query.ctorParameters = function () { return [
        { type: Apollo }
    ]; };
    Query = __decorate([
        Injectable()
    ], Query);
    return Query;
}());

var Mutation = /** @class */ (function () {
    function Mutation(apollo) {
        this.apollo = apollo;
        this.client = 'default';
    }
    Mutation.prototype.mutate = function (variables, options) {
        return this.apollo.use(this.client).mutate(__assign(__assign({}, options), { variables: variables, mutation: this.document }));
    };
    Mutation.ctorParameters = function () { return [
        { type: Apollo }
    ]; };
    Mutation = __decorate([
        Injectable()
    ], Mutation);
    return Mutation;
}());

var Subscription = /** @class */ (function () {
    function Subscription(apollo) {
        this.apollo = apollo;
        this.client = 'default';
    }
    Subscription.prototype.subscribe = function (variables, options, extra) {
        return this.apollo.use(this.client).subscribe(__assign(__assign({}, options), { variables: variables, query: this.document }), extra);
    };
    Subscription.ctorParameters = function () { return [
        { type: Apollo }
    ]; };
    Subscription = __decorate([
        Injectable()
    ], Subscription);
    return Subscription;
}());

var SelectPipe = /** @class */ (function () {
    function SelectPipe() {
    }
    SelectPipe.prototype.transform = function (obj, name) {
        if (name === void 0) { name = ''; }
        if (name !== '') {
            return obj && obj.data && obj.data[name];
        }
    };
    SelectPipe = __decorate([
        Pipe({
            name: 'select',
        })
    ], SelectPipe);
    return SelectPipe;
}());

var DECLARATIONS = [SelectPipe];
var ApolloModule = /** @class */ (function () {
    function ApolloModule(flags, alreadyThere) {
        var isStrict = pickFlag(flags, 'strict', true);
        if (isStrict && alreadyThere) {
            throw new Error([
                'ApolloModule is already loaded. Import it in the root module only.',
                '\nTo disable strict mode:',
                "\n            import { APOLLO_FLAGS } from 'apollo-angular';\n\n            @NgModule({\n              providers: [\n                {\n                  provide: APOLLO_FLAGS,\n                  useValue: {\n                    strict: false\n                  }\n                },\n              ]\n            })\n            export class AppModule {}\n\n          ",
            ].join('\n'));
        }
    }
    ApolloModule.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [APOLLO_FLAGS,] }] },
        { type: ApolloModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
    ]; };
    ApolloModule = __decorate([
        NgModule({
            declarations: DECLARATIONS,
            exports: DECLARATIONS,
        }),
        __param(0, Optional()), __param(0, Inject(APOLLO_FLAGS)),
        __param(1, Optional()), __param(1, SkipSelf())
    ], ApolloModule);
    return ApolloModule;
}());

var fetch = function (req, httpClient, extractFiles) {
    var shouldUseBody = ['POST', 'PUT', 'PATCH'].indexOf(req.method.toUpperCase()) !== -1;
    var shouldStringify = function (param) {
        return ['variables', 'extensions'].indexOf(param.toLowerCase()) !== -1;
    };
    var isBatching = req.body.length;
    var shouldUseMultipart = req.options && req.options.useMultipart;
    var multipartInfo;
    if (shouldUseMultipart) {
        if (isBatching) {
            return new Observable(function (observer) {
                return observer.error(new Error('File upload is not available when combined with Batching'));
            });
        }
        if (!shouldUseBody) {
            return new Observable(function (observer) {
                return observer.error(new Error('File upload is not available when GET is used'));
            });
        }
        multipartInfo = extractFiles(req.body);
        shouldUseMultipart = !!multipartInfo.files.size;
    }
    // `body` for some, `params` for others
    var bodyOrParams = {};
    if (isBatching) {
        if (!shouldUseBody) {
            return new Observable(function (observer) {
                return observer.error(new Error('Batching is not available for GET requests'));
            });
        }
        bodyOrParams = {
            body: req.body,
        };
    }
    else {
        var body = shouldUseMultipart ? multipartInfo.clone : req.body;
        if (shouldUseBody) {
            bodyOrParams = {
                body: body,
            };
        }
        else {
            var params = Object.keys(req.body).reduce(function (obj, param) {
                var value = req.body[param];
                obj[param] = shouldStringify(param) ? JSON.stringify(value) : value;
                return obj;
            }, {});
            bodyOrParams = { params: params };
        }
    }
    if (shouldUseMultipart && shouldUseBody) {
        var form_1 = new FormData();
        form_1.append('operations', JSON.stringify(bodyOrParams.body));
        var map_1 = {};
        var files = multipartInfo.files;
        var i_1 = 0;
        files.forEach(function (paths) {
            map_1[++i_1] = paths;
        });
        form_1.append('map', JSON.stringify(map_1));
        i_1 = 0;
        files.forEach(function (_, file) {
            form_1.append(++i_1 + '', file, file.name);
        });
        bodyOrParams.body = form_1;
    }
    // create a request
    return httpClient.request(req.method, req.url, __assign(__assign({ observe: 'response', responseType: 'json', reportProgress: false }, bodyOrParams), req.options));
};
function isHttpHeaders(headers) {
    return headers instanceof HttpHeaders;
}
function ensureHttpHeaders(headers) {
    return isHttpHeaders(headers) ? headers : new HttpHeaders(headers);
}
var mergeHeaders = function (source, destination) {
    if (source && destination) {
        var transformed_1 = {
            destination: ensureHttpHeaders(destination),
            source: ensureHttpHeaders(source),
        };
        var merged = transformed_1.destination
            .keys()
            .reduce(function (headers, name) {
            return headers.set(name, transformed_1.destination.getAll(name));
        }, transformed_1.source);
        return merged;
    }
    return ensureHttpHeaders(destination || source);
};
function prioritize() {
    var values = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        values[_i] = arguments[_i];
    }
    var picked = values.find(function (val) { return typeof val !== 'undefined'; });
    if (typeof picked === 'undefined') {
        return values[values.length - 1];
    }
    return picked;
}

// XXX find a better name for it
var HttpLinkHandler = /** @class */ (function (_super) {
    __extends(HttpLinkHandler, _super);
    function HttpLinkHandler(httpClient, options) {
        var _this = _super.call(this) || this;
        _this.httpClient = httpClient;
        _this.options = options;
        _this.requester = function (operation) {
            return new Observable$1(function (observer) {
                var context = operation.getContext();
                // decides which value to pick, Context, Options or to just use the default
                var pick = function (key, init) {
                    return prioritize(context[key], _this.options[key], init);
                };
                var includeQuery = pick('includeQuery', true);
                var includeExtensions = pick('includeExtensions', false);
                var method = pick('method', 'POST');
                var url = pick('uri', 'graphql');
                var withCredentials = pick('withCredentials');
                var useMultipart = pick('useMultipart');
                var req = {
                    method: method,
                    url: typeof url === 'function' ? url(operation) : url,
                    body: {
                        operationName: operation.operationName,
                        variables: operation.variables,
                    },
                    options: {
                        withCredentials: withCredentials,
                        useMultipart: useMultipart,
                        headers: _this.options.headers,
                    },
                };
                if (includeExtensions) {
                    req.body.extensions = operation.extensions;
                }
                if (includeQuery) {
                    req.body.query = print(operation.query);
                }
                if (context.headers) {
                    req.options.headers = mergeHeaders(req.options.headers, context.headers);
                }
                var sub = fetch(req, _this.httpClient, extractFiles).subscribe({
                    next: function (response) {
                        operation.setContext({ response: response });
                        observer.next(response.body);
                    },
                    error: function (err) { return observer.error(err); },
                    complete: function () { return observer.complete(); },
                });
                return function () {
                    if (!sub.closed) {
                        sub.unsubscribe();
                    }
                };
            });
        };
        return _this;
    }
    HttpLinkHandler.prototype.request = function (op) {
        return this.requester(op);
    };
    return HttpLinkHandler;
}(ApolloLink));
var HttpLink = /** @class */ (function () {
    function HttpLink(httpClient) {
        this.httpClient = httpClient;
    }
    HttpLink.prototype.create = function (options) {
        return new HttpLinkHandler(this.httpClient, options);
    };
    HttpLink.ctorParameters = function () { return [
        { type: HttpClient }
    ]; };
    HttpLink = __decorate([
        Injectable()
    ], HttpLink);
    return HttpLink;
}());

var HttpLinkModule = /** @class */ (function () {
    function HttpLinkModule() {
    }
    HttpLinkModule = __decorate([
        NgModule({
            providers: [HttpLink],
        })
    ], HttpLinkModule);
    return HttpLinkModule;
}());

var defaults = {
    batchInterval: 10,
    batchMax: 10,
    uri: 'graphql',
    method: 'POST',
};
var HttpBatchLinkHandler = /** @class */ (function (_super) {
    __extends(HttpBatchLinkHandler, _super);
    function HttpBatchLinkHandler(httpClient, options) {
        var _this = _super.call(this) || this;
        _this.httpClient = httpClient;
        _this.options = options;
        _this.batchInterval = options.batchInterval || defaults.batchInterval;
        _this.batchMax = options.batchMax || defaults.batchMax;
        var batchHandler = function (operations) {
            return new Observable$1(function (observer) {
                var body = _this.createBody(operations);
                var headers = _this.createHeaders(operations);
                var _a = _this.createOptions(operations), method = _a.method, uri = _a.uri, withCredentials = _a.withCredentials;
                if (typeof uri === 'function') {
                    throw new Error("Option 'uri' is a function, should be a string");
                }
                var req = {
                    method: method,
                    url: uri,
                    body: body,
                    options: {
                        withCredentials: withCredentials,
                        headers: headers,
                    },
                };
                var sub = fetch(req, _this.httpClient, function () {
                    throw new Error('File upload is not available when combined with Batching');
                }).subscribe({
                    next: function (result) { return observer.next(result.body); },
                    error: function (err) { return observer.error(err); },
                    complete: function () { return observer.complete(); },
                });
                return function () {
                    if (!sub.closed) {
                        sub.unsubscribe();
                    }
                };
            });
        };
        var batchKey = options.batchKey ||
            (function (operation) {
                return _this.createBatchKey(operation);
            });
        _this.batcher = new BatchLink({
            batchInterval: _this.batchInterval,
            batchMax: _this.batchMax,
            batchKey: batchKey,
            batchHandler: batchHandler,
        });
        return _this;
    }
    HttpBatchLinkHandler.prototype.createOptions = function (operations) {
        var context = operations[0].getContext();
        return {
            method: prioritize(context.method, this.options.method, defaults.method),
            uri: prioritize(context.uri, this.options.uri, defaults.uri),
            withCredentials: prioritize(context.withCredentials, this.options.withCredentials),
        };
    };
    HttpBatchLinkHandler.prototype.createBody = function (operations) {
        var _this = this;
        return operations.map(function (operation) {
            var includeExtensions = prioritize(operation.getContext().includeExtensions, _this.options.includeExtensions, false);
            var includeQuery = prioritize(operation.getContext().includeQuery, _this.options.includeQuery, true);
            var body = {
                operationName: operation.operationName,
                variables: operation.variables,
            };
            if (includeExtensions) {
                body.extensions = operation.extensions;
            }
            if (includeQuery) {
                body.query = print(operation.query);
            }
            return body;
        });
    };
    HttpBatchLinkHandler.prototype.createHeaders = function (operations) {
        return operations.reduce(function (headers, operation) {
            return mergeHeaders(headers, operation.getContext().headers);
        }, this.options.headers);
    };
    HttpBatchLinkHandler.prototype.createBatchKey = function (operation) {
        var context = operation.getContext();
        if (context.skipBatching) {
            return Math.random()
                .toString(36)
                .substr(2, 9);
        }
        var httpHeaders = context.headers && ensureHttpHeaders(context.headers);
        var headers = httpHeaders && httpHeaders.keys().map(function (k) { return httpHeaders.get(k); });
        var opts = JSON.stringify({
            includeQuery: context.includeQuery,
            includeExtensions: context.includeExtensions,
            headers: headers,
        });
        return prioritize(context.uri, this.options.uri) + opts;
    };
    HttpBatchLinkHandler.prototype.request = function (op) {
        return this.batcher.request(op);
    };
    return HttpBatchLinkHandler;
}(ApolloLink));
var HttpBatchLink = /** @class */ (function () {
    function HttpBatchLink(httpClient) {
        this.httpClient = httpClient;
    }
    HttpBatchLink.prototype.create = function (options) {
        return new HttpBatchLinkHandler(this.httpClient, options);
    };
    HttpBatchLink.ctorParameters = function () { return [
        { type: HttpClient }
    ]; };
    HttpBatchLink = __decorate([
        Injectable()
    ], HttpBatchLink);
    return HttpBatchLink;
}());

var HttpBatchLinkModule = /** @class */ (function () {
    function HttpBatchLinkModule() {
    }
    HttpBatchLinkModule = __decorate([
        NgModule({
            providers: [HttpBatchLink],
        })
    ], HttpBatchLinkModule);
    return HttpBatchLinkModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { APOLLO_FLAGS, APOLLO_NAMED_OPTIONS, APOLLO_OPTIONS, Apollo, ApolloBase, ApolloModule, HttpBatchLink, HttpBatchLinkHandler, HttpBatchLinkModule, HttpLink, HttpLinkHandler, HttpLinkModule, Mutation, Query, QueryRef, SelectPipe, Subscription, DECLARATIONS as ɵa };
//# sourceMappingURL=ngApollo.js.map
